# styles.rb: all style objects
# copyright (c) 2009 by Vincent Fourmond
  
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
  
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details (in the COPYING file).

require 'ctioga2/graphics/styles/base'

require 'ctioga2/graphics/styles/drawable'
require 'ctioga2/graphics/styles/arrows'
require 'ctioga2/graphics/styles/box'
require 'ctioga2/graphics/styles/location'
require 'ctioga2/graphics/styles/texts'
require 'ctioga2/graphics/styles/carrays'
require 'ctioga2/graphics/styles/curve'

require 'ctioga2/graphics/styles/gradients'
require 'ctioga2/graphics/styles/colormap'


require 'ctioga2/graphics/styles/errorbar'

require 'ctioga2/graphics/styles/sets'

require 'ctioga2/graphics/styles/axes'
require 'ctioga2/graphics/styles/map-axes'
require 'ctioga2/graphics/styles/background'
require 'ctioga2/graphics/styles/plot'

require 'ctioga2/graphics/styles/legend'


require 'ctioga2/graphics/styles/factory'

# Style sheets
require 'ctioga2/graphics/styles/sheet'
